@@ -9,7 +9,6 @@ knitr::opts_chunk$set(
 
 ## ---- message= FALSE, warning=FALSE, echo=FALSE-------------------------------
 library(here)
-library(ggplot2)
 library(DBI)
 library(dbplyr)
 library(dplyr)
@@ -35,21 +34,19 @@ knitr::include_graphics(here("vignettes/inc_rep_some_washout.png"))
 library(IncidencePrevalence)
 library(dplyr)
 library(tidyr)
-library(ggplot2)
 
 cdm <- mockIncidencePrevalenceRef(
   sampleSize = 50000,
   outPre = 0.5
 )
 
-cdm$denominator <- generateDenominatorCohortSet(
-  cdm = cdm,
-  startDate = as.Date("2008-01-01"),
-  endDate = as.Date("2012-01-01"),
+cdm <- generateDenominatorCohortSet(
+  cdm = cdm, name = "denominator",
+  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2012-01-01")),
   ageGroup = list(c(0, 150)),
   sex = "Both",
-  daysPriorHistory = 0, 
-  tablePrefix = "example_inc"
+  daysPriorHistory = 0,
+  temporary = FALSE,
 )
 
 cdm$denominator %>%
@@ -63,20 +60,13 @@ inc <- estimateIncidence(
   interval = "years",
   outcomeWashout = 0,
   repeatedEvents = FALSE,
-  tablePrefix = "example_inc"
+  temporary = FALSE
 )
 
 inc %>%
   glimpse()
 
-inc %>%
-  ggplot(aes(x = incidence_start_date, y = incidence_100000_pys,
-             ymin = incidence_100000_pys_95CI_lower,
-             ymax = incidence_100000_pys_95CI_upper)) +
-  geom_point() +
-  geom_errorbar(width = 0) +
-  scale_y_continuous(limits = c(0, NA)) +
-  theme_minimal()
+plotIncidence(inc)
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
 inc <- estimateIncidence(
@@ -86,20 +76,13 @@ inc <- estimateIncidence(
   interval = "years",
   outcomeWashout = Inf,
   repeatedEvents = FALSE,
-  tablePrefix = "example_inc"
+  temporary = FALSE
 )
 
 inc %>%
   glimpse()
 
-inc %>%
-  ggplot(aes(x = incidence_start_date, y = incidence_100000_pys,
-             ymin = incidence_100000_pys_95CI_lower,
-             ymax = incidence_100000_pys_95CI_upper)) +
-  geom_point() +
-  geom_errorbar(width = 0) +
-  scale_y_continuous(limits = c(0, NA)) +
-  theme_minimal()
+plotIncidence(inc)
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
 inc <- estimateIncidence(
@@ -109,20 +92,13 @@ inc <- estimateIncidence(
   interval = "years",
   outcomeWashout = 180,
   repeatedEvents = FALSE,
-  tablePrefix = "example_inc"
+  temporary = FALSE
 )
 
 inc %>%
   glimpse()
 
-inc %>%
-  ggplot(aes(x = incidence_start_date, y = incidence_100000_pys,
-             ymin = incidence_100000_pys_95CI_lower,
-             ymax = incidence_100000_pys_95CI_upper)) +
-  geom_point() +
-  geom_errorbar(width = 0) +
-  scale_y_continuous(limits = c(0, NA)) +
-  theme_minimal()
+plotIncidence(inc)
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
 inc <- estimateIncidence(
@@ -132,20 +108,13 @@ inc <- estimateIncidence(
   interval = "years",
   outcomeWashout = 180,
   repeatedEvents = TRUE,
-  tablePrefix = "example_inc"
+  temporary = FALSE
 )
 
 inc %>%
   glimpse()
 
-inc %>%
-  ggplot(aes(x = incidence_start_date, y = incidence_100000_pys,
-             ymin = incidence_100000_pys_95CI_lower,
-             ymax = incidence_100000_pys_95CI_upper)) +
-  geom_point() +
-  geom_errorbar(width = 0) +
-  scale_y_continuous(limits = c(0, NA)) +
-  theme_minimal()
+plotIncidence(inc)
 
 ## ---- message=TRUE, warning=FALSE---------------------------------------------
 inc <- estimateIncidence(
@@ -157,7 +126,7 @@ inc <- estimateIncidence(
   outcomeWashout = 180,
   repeatedEvents = TRUE,
   minCellCount = 0,
-  tablePrefix = "example_inc"
+  temporary = FALSE
 )
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
@@ -168,18 +137,18 @@ inc <- estimateIncidence(
   interval = c("Years"),
   outcomeWashout = c(0, 180),
   repeatedEvents = TRUE,
-  tablePrefix = "example_study", # returnParticipants can only be TRUE if tablePrefix is not null
+  temporary = FALSE,
   returnParticipants = TRUE
 )
-incidenceSet(inc)
 incidenceAttrition(inc)
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
-participants(inc, analysisId = 1) %>% 
+participants(inc, analysisId = 1) %>%
   glimpse()
 
 ## ---- message= FALSE, warning=FALSE-------------------------------------------
 CDMConnector::listTables(attr(cdm, "dbcon"))
-CDMConnector::dropTable(cdm = cdm, name = starts_with("example"))
+CDMConnector::dropTable(cdm = cdm, name = starts_with("denominator"))
+CDMConnector::dropTable(cdm = cdm, name = starts_with("inc_participants"))
 CDMConnector::listTables(attr(cdm, "dbcon"))
 
